@@ -1,4 +1,5 @@
 import * as React from 'react';
+import * as _ from 'lodash';
 import {
   Chart,
   ChartArea,
@@ -8,12 +9,9 @@ import {
   ChartVoronoiContainer,
   getCustomTheme,
   ChartGroup,
-  ChartTooltip,
 } from '@patternfly/react-charts';
-import {
-  global_warning_color_100 as warningColor,
-  global_danger_color_100 as dangerColor,
-} from '@patternfly/react-tokens';
+import { global_warning_color_100 as warningColor } from '@patternfly/react-tokens/dist/js/global_warning_color_100';
+import { global_danger_color_100 as dangerColor } from '@patternfly/react-tokens/dist/js/global_danger_color_100';
 import { processFrame, ByteDataTypes } from '@console/shared/src/graph-helper/data-utils';
 import { twentyFourHourTime } from '../utils/datetime';
 import { humanizeNumber, useRefWidth, Humanize } from '../utils';
@@ -21,9 +19,10 @@ import { PrometheusEndpoint } from './helpers';
 import { PrometheusGraph, PrometheusGraphLink } from './prometheus-graph';
 import { usePrometheusPoll } from './prometheus-poll-hook';
 import { areaTheme } from './themes';
-import { DataPoint } from './';
-import { getRangeVectorStats } from './utils';
+import { DataPoint, CursorVoronoiContainer } from './';
+import { mapLimitsRequests } from './utils';
 import { GraphEmpty } from './graph-empty';
+import { ChartLegendTooltip } from './tooltip';
 
 const DEFAULT_HEIGHT = 180;
 const DEFAULT_SAMPLES = 60;
@@ -40,6 +39,7 @@ export const chartStatusColors = {
   [AreaChartStatus.WARNING]: warningColor.value,
 };
 
+// @ts-ignore
 export const AreaChart: React.FC<AreaChartProps> = ({
   className,
   data = [],
@@ -49,65 +49,78 @@ export const AreaChart: React.FC<AreaChartProps> = ({
   loading = true,
   padding,
   query,
-  theme = getCustomTheme(ChartThemeColor.blue, ChartThemeVariant.light, areaTheme),
   tickCount = DEFAULT_TICK_COUNT,
   title,
   xAxis = true,
   yAxis = true,
   chartStyle,
   byteDataType = '',
+  showAllTooltip,
 }) => {
+  // Note: Victory incorrectly typed ThemeBaseProps.padding as number instead of PaddingProps
+  // @ts-ignore
+  const theme = getCustomTheme(ChartThemeColor.blue, ChartThemeVariant.light, areaTheme);
   const [containerRef, width] = useRefWidth();
-  const [processedData, setProcessedData] = React.useState(data);
-  const [unit, setUnit] = React.useState('');
-
-  React.useEffect(() => {
+  const { processedData, unit } = React.useMemo(() => {
+    const nonEmptyDataSets = data.filter((dataSet) => dataSet?.length);
     if (byteDataType) {
-      const result = processFrame(data, byteDataType);
-      setProcessedData(result.processedData);
-      setUnit(result.unit);
-    } else {
-      setProcessedData(data);
+      return processFrame(nonEmptyDataSets, byteDataType);
     }
+    return { processedData: nonEmptyDataSets, unit: '' };
   }, [byteDataType, data]);
 
+  // If every data point of every data set is 0, force y-domain to [0,1]
+  const allZero = React.useMemo(
+    () => _.every(processedData, (dataSet) => _.every(dataSet, ({ y }) => y === 0)),
+    [processedData],
+  );
+
   const tickFormat = React.useCallback((tick) => `${humanize(tick, unit, unit).string}`, [
     humanize,
     unit,
   ]);
 
   const getLabel = React.useCallback(
-    (prop) => {
-      const { x, y, description } = prop.datum as DataPoint<Date>;
+    (prop, includeDate = true) => {
+      const { x, y } = prop.datum as DataPoint<Date>;
       const value = humanize(y, unit, unit).string;
       const date = formatDate(x);
-      if (!description) {
-        return `${value} at ${date}`;
-      }
-      return description(date, value);
+      return includeDate ? `${value} at ${date}` : value;
     },
     [humanize, unit, formatDate],
   );
 
-  const multiLine = data && data.filter((d) => !!d).length > 1;
+  const multiLine = processedData?.length > 1;
 
-  const container = (
-    <ChartVoronoiContainer
-      voronoiDimension="x"
-      labels={getLabel}
-      activateData={false}
-      labelComponent={
-        <ChartTooltip
-          centerOffset={multiLine ? { x: 0, y: -40 } : undefined}
-          pointerLength={multiLine ? 40 : undefined}
+  const container = React.useMemo(() => {
+    if (multiLine) {
+      const legendData = processedData.map((d) => ({
+        childName: d[0].description,
+        name: d[0].description,
+        symbol: d[0].symbol,
+      }));
+      return (
+        <CursorVoronoiContainer
+          activateData={false}
+          cursorDimension="x"
+          labels={(props) => getLabel(props, false)}
+          labelComponent={
+            <ChartLegendTooltip
+              stack={showAllTooltip}
+              legendData={legendData}
+              title={(d) => (showAllTooltip ? formatDate(d[0].x) : getLabel({ datum: d[0] }))}
+            />
+          }
+          voronoiDimension="x"
         />
-      }
-    />
-  );
+      );
+    }
+    return <ChartVoronoiContainer voronoiDimension="x" labels={getLabel} activateData={false} />;
+  }, [formatDate, getLabel, multiLine, processedData, showAllTooltip]);
 
   return (
     <PrometheusGraph className={className} ref={containerRef} title={title}>
-      {data && data[0] && data[0].length ? (
+      {processedData?.length ? (
         <PrometheusGraphLink query={query}>
           <Chart
             containerComponent={container}
@@ -117,12 +130,18 @@ export const AreaChart: React.FC<AreaChartProps> = ({
             theme={theme}
             scale={{ x: 'time', y: 'linear' }}
             padding={padding}
+            {...(allZero && { domain: { y: [0, 1] } })}
           >
             {xAxis && <ChartAxis tickCount={tickCount} tickFormat={formatDate} />}
             {yAxis && <ChartAxis dependentAxis tickCount={tickCount} tickFormat={tickFormat} />}
             <ChartGroup>
               {processedData.map((datum, index) => (
-                <ChartArea key={index} data={datum} style={chartStyle && chartStyle[index]} />
+                <ChartArea
+                  key={index}
+                  data={datum}
+                  style={chartStyle && chartStyle[index]}
+                  name={datum[0]?.description}
+                />
               ))}
             </ChartGroup>
           </Chart>
@@ -137,12 +156,14 @@ export const AreaChart: React.FC<AreaChartProps> = ({
 export const Area: React.FC<AreaProps> = ({
   namespace,
   query,
+  limitQuery,
+  requestedQuery,
   samples = DEFAULT_SAMPLES,
   timeout,
   timespan = DEFAULT_TIMESPAN,
   ...rest
 }) => {
-  const [response, , loading] = usePrometheusPoll({
+  const [utilization, , utilizationLoading] = usePrometheusPoll({
     endpoint: PrometheusEndpoint.QUERY_RANGE,
     namespace,
     query,
@@ -150,11 +171,33 @@ export const Area: React.FC<AreaProps> = ({
     timeout,
     timespan,
   });
-  const data = getRangeVectorStats(response);
-  return <AreaChart data={[data]} loading={loading} query={query} {...rest} />;
+  const [limit, , limitLoading] = usePrometheusPoll({
+    endpoint: PrometheusEndpoint.QUERY_RANGE,
+    namespace,
+    query: limitQuery,
+    samples,
+    timeout,
+    timespan,
+  });
+  const [requested, , requestedLoading] = usePrometheusPoll({
+    endpoint: PrometheusEndpoint.QUERY_RANGE,
+    namespace,
+    query: requestedQuery,
+    samples,
+    timeout,
+    timespan,
+  });
+  const { data, chartStyle } = mapLimitsRequests(utilization, limit, requested);
+  const loading =
+    utilizationLoading &&
+    (limitQuery ? limitLoading : true) &&
+    (requestedQuery ? requestedLoading : true);
+  return (
+    <AreaChart data={data} loading={loading} query={query} chartStyle={chartStyle} {...rest} />
+  );
 };
 
-type AreaChartProps = {
+export type AreaChartProps = {
   className?: string;
   formatDate?: (date: Date) => string;
   humanize?: Humanize;
@@ -170,6 +213,7 @@ type AreaChartProps = {
   padding?: object;
   chartStyle?: object[];
   byteDataType?: ByteDataTypes; //Use this to process the whole data frame at once
+  showAllTooltip?: boolean;
 };
 
 type AreaProps = AreaChartProps & {
@@ -179,4 +223,6 @@ type AreaProps = AreaChartProps & {
   timeout?: string;
   timespan?: number;
   byteDataType?: ByteDataTypes;
+  limitQuery?: string;
+  requestedQuery?: string;
 };
